@@ -38,7 +38,8 @@ class Fargate(AwsPy):
         try:
             request = requests.get(self.ecs_container_metadata_uri_v4, timeout=3)
             if request.status_code == 200:
-                json_metadata: str = request.json()
+                raw_metadata: str = request.text
+                json_metadata: dict = json.loads(raw_metadata)
                 return json_metadata
             else:
                 raise RuntimeError(
